@@ -18,8 +18,8 @@
 package router
 
 import (
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/protocol"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/protocol"
 )
 
 // Chain
@@ -29,21 +29,4 @@ type Chain interface {
 	SetInvokers([]protocol.Invoker)
 	// AddRouters Add routers
 	AddRouters([]PriorityRouter)
-	// GetNotifyChan get notify channel of this chain
-	GetNotifyChan() chan struct{}
-	// Detect Route State
-	DetectRoute() (RouteSnapshot, error)
-	// listens on events to update the address cache
-	Loop()
-}
-
-// RouteSnapshot is the snapshot of Route
-type RouteSnapshot struct {
-	Invokers       []protocol.Invoker
-	RouteSnapshots []string
-}
-
-// nolint
-func (rs *RouteSnapshot) AddRouteSnapshot(msg string) {
-	rs.RouteSnapshots = append(rs.RouteSnapshots, msg)
 }
