@@ -21,8 +21,6 @@ import (
 	"time"
 )
 
-var (
-	// The value will be 10^6
-	// 1ms = 10^6ns
-	MsToNanoRate = int64(time.Millisecond / time.Nanosecond)
-)
+// The value will be 10^6
+// 1ms = 10^6ns
+var MsToNanoRate = int64(time.Millisecond / time.Nanosecond)
