@@ -18,14 +18,12 @@
 package extension
 
 import (
-	"github.com/apache/dubbo-go/metadata/mapping"
+	"dubbo.apache.org/dubbo-go/v3/metadata/mapping"
 )
 
 type ServiceNameMappingCreator func() mapping.ServiceNameMapping
 
-var (
-	globalNameMappingCreator ServiceNameMappingCreator
-)
+var globalNameMappingCreator ServiceNameMappingCreator
 
 func SetGlobalServiceNameMapping(nameMappingCreator ServiceNameMappingCreator) {
 	globalNameMappingCreator = nameMappingCreator
