@@ -18,11 +18,11 @@
 package config_center
 
 import (
-	"github.com/apache/dubbo-go/common"
+	"dubbo.apache.org/dubbo-go/v3/common"
 )
 
-// Configurator supports GetURL and constructor
+// Configurator supports GetUrl and constructor
 type Configurator interface {
-	GetURL() *common.URL
+	GetUrl() *common.URL
 	Configure(url *common.URL)
 }
