@@ -23,14 +23,13 @@ import (
 )
 
 type User struct {
-	Id   string
+	ID   string
 	Name string
 	Age  int32
 	Time time.Time
 }
 
-type UserProvider struct {
-}
+type UserProvider struct{}
 
 func (u *UserProvider) GetUser(ctx context.Context, req []interface{}) (*User, error) {
 	rsp := User{"A001", "Alex Stocks", 18, time.Now()}
