@@ -29,20 +29,21 @@ import (
 )
 
 import (
-	"github.com/apache/dubbo-go/cluster"
-	"github.com/apache/dubbo-go/cluster/directory"
-	"github.com/apache/dubbo-go/cluster/router/chain"
-	"github.com/apache/dubbo-go/common"
-	"github.com/apache/dubbo-go/common/constant"
-	"github.com/apache/dubbo-go/common/extension"
-	"github.com/apache/dubbo-go/common/logger"
-	"github.com/apache/dubbo-go/config"
-	"github.com/apache/dubbo-go/config_center"
-	_ "github.com/apache/dubbo-go/config_center/configurator"
-	"github.com/apache/dubbo-go/protocol"
-	"github.com/apache/dubbo-go/protocol/protocolwrapper"
-	"github.com/apache/dubbo-go/registry"
-	"github.com/apache/dubbo-go/remoting"
+	"dubbo.apache.org/dubbo-go/v3/cluster/directory"
+	"dubbo.apache.org/dubbo-go/v3/cluster/directory/base"
+	"dubbo.apache.org/dubbo-go/v3/cluster/directory/static"
+	"dubbo.apache.org/dubbo-go/v3/cluster/router/chain"
+	"dubbo.apache.org/dubbo-go/v3/common"
+	"dubbo.apache.org/dubbo-go/v3/common/constant"
+	"dubbo.apache.org/dubbo-go/v3/common/extension"
+	"dubbo.apache.org/dubbo-go/v3/common/logger"
+	"dubbo.apache.org/dubbo-go/v3/config"
+	"dubbo.apache.org/dubbo-go/v3/config_center"
+	_ "dubbo.apache.org/dubbo-go/v3/config_center/configurator"
+	"dubbo.apache.org/dubbo-go/v3/protocol"
+	"dubbo.apache.org/dubbo-go/v3/protocol/protocolwrapper"
+	"dubbo.apache.org/dubbo-go/v3/registry"
+	"dubbo.apache.org/dubbo-go/v3/remoting"
 )
 
 func init() {
@@ -52,7 +53,7 @@ func init() {
 // RegistryDirectory implementation of Directory:
 // Invoker list returned from this Directory's list method have been filtered by Routers
 type RegistryDirectory struct {
-	directory.BaseDirectory
+	base.Directory
 	cacheInvokers                  []protocol.Invoker
 	invokersLock                   sync.RWMutex
 	serviceType                    string
@@ -63,34 +64,29 @@ type RegistryDirectory struct {
 	configurators                  []config_center.Configurator
 	consumerConfigurationListener  *consumerConfigurationListener
 	referenceConfigurationListener *referenceConfigurationListener
-	//serviceKey                     string
-	//forbidden                      atomic.Bool
+	// serviceKey                     string
+	// forbidden                      atomic.Bool
 	registerLock sync.Mutex // this lock if for register
-	// healthState
-	serviceHealthState *protocol.ServiceHealthState
 }
 
 // NewRegistryDirectory will create a new RegistryDirectory
-func NewRegistryDirectory(url *common.URL, registry registry.Registry) (cluster.Directory, error) {
+func NewRegistryDirectory(url *common.URL, registry registry.Registry) (directory.Directory, error) {
 	if url.SubURL == nil {
 		return nil, perrors.Errorf("url is invalid, suburl can not be nil")
 	}
 	logger.Debugf("new RegistryDirectory for service :%s.", url.Key())
 	dir := &RegistryDirectory{
-		BaseDirectory:    directory.NewBaseDirectory(url),
+		Directory:        base.NewDirectory(url),
 		cacheInvokers:    []protocol.Invoker{},
 		cacheInvokersMap: &sync.Map{},
 		serviceType:      url.SubURL.Service(),
 		registry:         registry,
-		// init serviceHealthState
-		serviceHealthState: protocol.NewServiceState(url.SubURL.ServiceKey()),
 	}
 
 	dir.consumerURL = dir.getConsumerUrl(url.SubURL)
 
-	if routerChain, err := chain.NewRouterChain(dir.consumerURL); err == nil {
-		dir.BaseDirectory.SetRouterChain(routerChain)
-		dir.AddRouters(fileBasedRouterUrls())
+	if routerChain, err := chain.NewRouterChain(); err == nil {
+		dir.Directory.SetRouterChain(routerChain)
 	} else {
 		logger.Warnf("fail to create router chain with url: %s, err is: %v", url.SubURL, err)
 	}
@@ -160,9 +156,9 @@ func (dir *RegistryDirectory) refreshAllInvokers(events []*registry.ServiceEvent
 				"please check the Action of ServiceEvent should be EventTypeUpdate")
 		}
 		// Originally it will Merge URL many times, now we just execute once.
-		// MergeUrl is executed once and put the result into Event. After this, the key will get from Event.Key().
+		// MergeURL is executed once and put the result into Event. After this, the key will get from Event.Key().
 		newUrl := dir.convertUrl(event)
-		newUrl = common.MergeUrl(newUrl, referenceUrl)
+		newUrl = common.MergeURL(newUrl, referenceUrl)
 		dir.overrideUrl(newUrl)
 		event.Update(newUrl)
 	}
@@ -190,21 +186,18 @@ func (dir *RegistryDirectory) refreshAllInvokers(events []*registry.ServiceEvent
 			}
 		}
 		// loop the updateEvents
-		var routerUrls []*common.URL
 		for _, event := range addEvents {
-			logger.Debugf("registry update, result{%s}", event)
-			if event.Service != nil {
-				logger.Infof("selector add service url{%s}", event.Service.String())
+			logger.Debugf("[Registry Directory] registry update, result{%s}", event)
+			if event != nil && event.Service != nil {
+				logger.Infof("[Registry Directory] selector add service url{%s}", event.Service.String())
 			}
-			if event != nil && event.Service != nil && constant.ROUTER_PROTOCOL == event.Service.Protocol {
-				routerUrls = append(routerUrls, event.Service)
-				continue
+			if event != nil && event.Service != nil && constant.RouterProtocol == event.Service.Protocol {
+				dir.configRouters()
 			}
 			if oldInvoker, _ := dir.doCacheInvoker(event.Service, event); oldInvoker != nil {
 				oldInvokers = append(oldInvokers, oldInvoker)
 			}
 		}
-		dir.AddRouters(append(fileBasedRouterUrls(), routerUrls...))
 	}()
 	dir.setNewInvokers()
 	// destroy unused invokers
@@ -230,7 +223,7 @@ func (dir *RegistryDirectory) invokerCacheKey(event *registry.ServiceEvent) stri
 		return event.Key()
 	}
 	referenceUrl := dir.GetDirectoryUrl().SubURL
-	newUrl := common.MergeUrl(event.Service, referenceUrl)
+	newUrl := common.MergeURL(event.Service, referenceUrl)
 	event.Update(newUrl)
 	return event.Key()
 }
@@ -241,27 +234,24 @@ func (dir *RegistryDirectory) setNewInvokers() {
 	dir.invokersLock.Lock()
 	defer dir.invokersLock.Unlock()
 	dir.cacheInvokers = newInvokers
-	routerChain := dir.RouterChain()
-	if routerChain != nil {
-		routerChain.SetInvokers(newInvokers)
-	}
+	dir.RouterChain().SetInvokers(newInvokers)
 }
 
 // cacheInvokerByEvent caches invokers from the service event
 func (dir *RegistryDirectory) cacheInvokerByEvent(event *registry.ServiceEvent) (protocol.Invoker, error) {
 	// judge is override or others
 	if event != nil {
+
 		switch event.Action {
 		case remoting.EventTypeAdd, remoting.EventTypeUpdate:
 			u := dir.convertUrl(event)
-			logger.Infof("selector add service url{%s}", event.Service)
-			if u != nil && constant.ROUTER_PROTOCOL == u.Protocol {
-				dir.AddRouters(append(fileBasedRouterUrls(), u))
-				return nil, nil
+			logger.Infof("[Registry Directory] selector add service url{%s}", event.Service)
+			if u != nil && constant.RouterProtocol == u.Protocol {
+				dir.configRouters()
 			}
 			return dir.cacheInvoker(u, event), nil
 		case remoting.EventTypeDel:
-			logger.Infof("selector delete service url{%s}", event.Service)
+			logger.Infof("[Registry Directory] selector delete service url{%s}", event.Service)
 			return dir.uncacheInvoker(event), nil
 		default:
 			return nil, fmt.Errorf("illegal event type: %v", event.Action)
@@ -270,37 +260,34 @@ func (dir *RegistryDirectory) cacheInvokerByEvent(event *registry.ServiceEvent)
 	return nil, nil
 }
 
+// configRouters configures dynamic routers into the router chain, but, the current impl is incorrect, see FIXME above.
+func (dir *RegistryDirectory) configRouters() {
+}
+
 // convertUrl processes override:// and router://
 func (dir *RegistryDirectory) convertUrl(res *registry.ServiceEvent) *common.URL {
 	ret := res.Service
-	if ret.Protocol == constant.OVERRIDE_PROTOCOL || // 1.for override url in 2.6.x
-		ret.GetParam(constant.CATEGORY_KEY, constant.DEFAULT_CATEGORY) == constant.CONFIGURATORS_CATEGORY {
+	if ret.Protocol == constant.OverrideProtocol || // 1.for override url in 2.6.x
+		ret.GetParam(constant.CategoryKey, constant.DefaultCategory) == constant.ConfiguratorsCategory {
 		dir.configurators = append(dir.configurators, extension.GetDefaultConfigurator(ret))
 		ret = nil
-	} else if ret.Protocol == constant.ROUTER_PROTOCOL || // 2.for router
-		ret.GetParam(constant.CATEGORY_KEY, constant.DEFAULT_CATEGORY) == constant.ROUTER_CATEGORY {
+	} else if ret.Protocol == constant.RouterProtocol || // 2.for router
+		ret.GetParam(constant.CategoryKey, constant.DefaultCategory) == constant.RouterCategory {
 		ret = nil
 	}
 	return ret
 }
 
 func (dir *RegistryDirectory) toGroupInvokers() []protocol.Invoker {
-	var (
-		err             error
-		newInvokersList []protocol.Invoker
-	)
 	groupInvokersMap := make(map[string][]protocol.Invoker)
 
 	dir.cacheInvokersMap.Range(func(key, value interface{}) bool {
-		newInvokersList = append(newInvokersList, value.(protocol.Invoker))
+		invoker := value.(protocol.Invoker)
+		group := invoker.GetURL().GetParam(constant.GroupKey, "")
+		groupInvokersMap[group] = append(groupInvokersMap[group], invoker)
 		return true
 	})
 
-	for _, invoker := range newInvokersList {
-		group := invoker.GetURL().GetParam(constant.GROUP_KEY, "")
-
-		groupInvokersMap[group] = append(groupInvokersMap[group], invoker)
-	}
 	groupInvokersList := make([]protocol.Invoker, 0, len(groupInvokersMap))
 	if len(groupInvokersMap) == 1 {
 		// len is 1 it means no group setting ,so do not need cluster again
@@ -309,14 +296,18 @@ func (dir *RegistryDirectory) toGroupInvokers() []protocol.Invoker {
 		}
 	} else {
 		for _, invokers := range groupInvokersMap {
-			staticDir := directory.NewStaticDirectory(invokers)
-			cst := extension.GetCluster(dir.GetURL().SubURL.GetParam(constant.CLUSTER_KEY, constant.DEFAULT_CLUSTER))
+			staticDir := static.NewDirectory(invokers)
+			clusterKey := dir.GetURL().SubURL.GetParam(constant.ClusterKey, constant.DefaultCluster)
+			cluster, err := extension.GetCluster(clusterKey)
+			if err != nil {
+				panic(err)
+			}
 			err = staticDir.BuildRouterChain(invokers)
 			if err != nil {
 				logger.Error(err)
 				continue
 			}
-			groupInvokersList = append(groupInvokersList, cst.Join(staticDir))
+			groupInvokersList = append(groupInvokersList, cluster.Join(staticDir))
 		}
 	}
 
@@ -330,6 +321,7 @@ func (dir *RegistryDirectory) uncacheInvoker(event *registry.ServiceEvent) proto
 
 func (dir *RegistryDirectory) uncacheInvokerWithKey(key string) protocol.Invoker {
 	logger.Debugf("service will be deleted in cache invokers: invokers key is  %s!", key)
+	protocol.RemoveUrlKeyUnhealthyStatus(key)
 	if cacheInvoker, ok := dir.cacheInvokersMap.Load(key); ok {
 		dir.cacheInvokersMap.Delete(key)
 		return cacheInvoker.(protocol.Invoker)
@@ -353,7 +345,7 @@ func (dir *RegistryDirectory) cacheInvoker(url *common.URL, event *registry.Serv
 	}
 	// check the url's protocol is equal to the protocol which is configured in reference config or referenceUrl is not care about protocol
 	if url.Protocol == referenceUrl.Protocol || referenceUrl.Protocol == "" {
-		newUrl := common.MergeUrl(url, referenceUrl)
+		newUrl := common.MergeURL(url, referenceUrl)
 		dir.overrideUrl(newUrl)
 		event.Update(newUrl)
 		if v, ok := dir.doCacheInvoker(newUrl, event); ok {
@@ -404,15 +396,10 @@ func (dir *RegistryDirectory) List(invocation protocol.Invocation) []protocol.In
 	return routerChain.Route(dir.consumerURL, invocation)
 }
 
-// Fetch ServiceHealthState
-func (dir *RegistryDirectory) ServiceHealthState() *protocol.ServiceHealthState {
-	return dir.serviceHealthState
-}
-
 // IsAvailable  whether the directory is available
 func (dir *RegistryDirectory) IsAvailable() bool {
-	if !dir.BaseDirectory.IsAvailable() {
-		return dir.BaseDirectory.IsAvailable()
+	if !dir.Directory.IsAvailable() {
+		return dir.Directory.IsAvailable()
 	}
 
 	for _, ivk := range dir.cacheInvokers {
@@ -427,7 +414,7 @@ func (dir *RegistryDirectory) IsAvailable() bool {
 // Destroy method
 func (dir *RegistryDirectory) Destroy() {
 	// TODO:unregister & unsubscribe
-	dir.BaseDirectory.Destroy(func() {
+	dir.Directory.Destroy(func() {
 		invokers := dir.cacheInvokers
 		dir.cacheInvokers = []protocol.Invoker{}
 		for _, ivk := range invokers {
@@ -466,15 +453,6 @@ func doOverrideUrl(configurators []config_center.Configurator, targetUrl *common
 	}
 }
 
-// build static configured router from local router config
-func fileBasedRouterUrls() []*common.URL {
-	var urls []*common.URL
-	for _, v := range config.GetRouterURLSet().Values() {
-		urls = append(urls, v.(*common.URL))
-	}
-	return urls
-}
-
 type referenceConfigurationListener struct {
 	registry.BaseConfigurationListener
 	directory *RegistryDirectory
@@ -484,7 +462,7 @@ type referenceConfigurationListener struct {
 func newReferenceConfigurationListener(dir *RegistryDirectory, url *common.URL) *referenceConfigurationListener {
 	listener := &referenceConfigurationListener{directory: dir, url: url}
 	listener.InitWith(
-		url.EncodedServiceKey()+constant.CONFIGURATORS_SUFFIX,
+		url.EncodedServiceKey()+constant.ConfiguratorSuffix,
 		listener,
 		extension.GetDefaultConfiguratorFunc(),
 	)
@@ -506,8 +484,9 @@ type consumerConfigurationListener struct {
 
 func newConsumerConfigurationListener(dir *RegistryDirectory) *consumerConfigurationListener {
 	listener := &consumerConfigurationListener{directory: dir}
+	application := config.GetRootConfig().Application
 	listener.InitWith(
-		config.GetConsumerConfig().ApplicationConfig.Name+constant.CONFIGURATORS_SUFFIX,
+		application.Name+constant.ConfiguratorSuffix,
 		listener,
 		extension.GetDefaultConfiguratorFunc(),
 	)
