@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package remoting
 
 import (
@@ -24,17 +25,16 @@ import (
 type Codec interface {
 	EncodeRequest(request *Request) (*bytes.Buffer, error)
 	EncodeResponse(response *Response) (*bytes.Buffer, error)
-	Decode(data []byte) (*DecodeResult, int, error)
+	Decode(data []byte) (DecodeResult, int, error)
 }
 
 type DecodeResult struct {
+	// IsRequest indicates whether the current request is a heartbeat request
 	IsRequest bool
 	Result    interface{}
 }
 
-var (
-	codec = make(map[string]Codec, 2)
-)
+var codec = make(map[string]Codec, 2)
 
 func RegistryCodec(protocol string, codecTmp Codec) {
 	codec[protocol] = codecTmp
